;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "hl-todo" "20260504.1724"
  "Highlight TODO and similar keywords."
  '((emacs  "26.1")
    (compat "31.0"))
  :url "https://github.com/tarsius/hl-todo"
  :commit "cdd8a5bc8d5a41540df3dea88d5f62a6c3f4cfd3"
  :revdesc "cdd8a5bc8d5a"
  :keywords '("convenience")
  :authors '(("Jonas Bernoulli" . "emacs.hl-todo@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.hl-todo@jonas.bernoulli.dev")))
